@@ -1,23 +1,40 @@
 plot.BchronologyRun <-
-function(x,...) {
+function(x, 
+         dateHeight = 30, 
+         ...) {
+  
   # x contains the output from a run of the Bchronology function
   
+  # Get extra arguments if provided
+  ex = list(...)#as.list(substitute(list(...)))[-1L]
+
   # Get chronology ranges
   chronLow = apply(x$thetaPredict,2,'quantile',probs=0.025)
   chronMed = apply(x$thetaPredict,2,'quantile',probs=0.5)
   chronHigh = apply(x$thetaPredict,2,'quantile',probs=0.975)
   
-  xLimits = range(c(chronLow,chronHigh))
   yLimits = range(x$predictPositions)
   for(i in 1:length(x$calAges)) {
     yLimits = range(c(yLimits,x$calAges[[i]]$positions))
   }
   yLimits = c(yLimits[1],yLimits[2])
-  dateHeight=0.2*diff(pretty(yLimits))[1]
+  #dateHeight=0.2*diff(pretty(yLimits))[1]
   yLimits[1] = yLimits[1]-dateHeight
+  ex$ylim = rev(yLimits)
+  if(is.null(ex$xlim)) ex$xlim = rev(range(c(chronLow,chronHigh)))
+  if(is.null(ex$xlab)) ex$xlab = 'Age'
+  if(is.null(ex$ylab)) ex$ylab = 'Depth'
+  if(is.null(ex$las)) ex$las = 1
+  if(is.null(ex$main)) ex$main = 'Bchronology plot'
+  ex$x = 1
+  ex$y = 1
+  ex$type = 'n'
   
-  # Create the plot
-  graphics::plot(1,1,xlim=rev(xLimits),ylim=rev(yLimits),type="n",...)
+  # Modify the arguments if necessary
+  args = utils::modifyList(ex, list(...))
+  
+  # Create the outline plot
+  do.call("plot", args)
   graphics::grid()
   
   # Add in the dates
